local L = LibStub("AceLocale-3.0"):GetLocale("RaidSnacks", true)
local raid_normal = {"42BWD", "45BTW", "46TFW", "41BAH", "44FIR", "43DGS", "52MGS", "53TES", "51HOF", "54TOT", "55SOO", "61BRF", "62HGM", "63HFC"}
local raid_heroic = {"42BWD", "45BTW", "46TFW", "44FIR", "43DGS", "52MGS", "53TES", "51HOF", "54TOT", "55SOO", "61BRF", "62HGM", "63HFC"}
local raid_lfr = {"43DGS", "52MGS", "53TES", "51HOF", "54TOT", "55SOO", "61BRF", "62HGM", "63HFC"}
local raid_mythic = {"55SOO", "61BRF", "62HGM", "63HFC"}

local function MakeList(raids)
    local list = {}
    local colours = {["4"] = "ff778899", ["5"] = "ff6e8b3d", ["6"] = "ffffd700"}
    local expsettings = {["4"] = RaidSnacks.db.char.hidecat, ["5"] = RaidSnacks.db.char.hidemop, ["6"] = RaidSnacks.db.char.hidewod}
    for _, r in pairs(raids) do 
        local exp = string.sub(r,1,1)
        if not expsettings[exp] then
            local c = colours[exp]
            list[r] = "|c" .. c .. GetMapNameByID(map_id_list[r])
        end
    end
    return list
end


local options = {
    name = "RaidSnacks",
    handler = RaidSnacks,
    type = 'group',
    args = {
        raidsn = { -- Normal raids select
            type = "multiselect",
            name = L["Normal Raids"],
            desc = L["Raid instances where you want to log combat"],
            values = MakeList(raid_normal),
            tristate = false,
            get = function(info, raid) return RaidSnacks:GetSetting("normal", raid) end,
            set = function(info, raid, value) RaidSnacks:SetSetting("normal", raid, value) end,
            order = 14,
        },
        raidsh = { -- Heroic raids select
            type = "multiselect",
            name = L["Heroic Raids"],
            desc = L["Raid instances where you want to log combat"],
            values = MakeList(raid_heroic),
            tristate = false,
            get = function(info, raid) return RaidSnacks:GetSetting("heroic", raid) end,
            set = function(info, raid, value) RaidSnacks:SetSetting("heroic", raid, value) end,
            order = 15,
        },
        mythic = { -- Mythic raids select
            type = "multiselect",
            name = L["Mythic Raids"],
            desc = L["Raid instances where you want to log combat"],
            values = MakeList(raid_mythic),
            tristate = false,
            get = function(info, raid) return RaidSnacks:GetSetting("mythic", raid) end,
            set = function(info, raid, value) RaidSnacks:SetSetting("mythic", raid, value) end,
            order = 16,
        },
        lfr = { -- LFR raids select
            type = "multiselect",
            name = L["LFR Raids"],
            desc = L["Raid finder instances where you want to log combat"],
            values = MakeList(raid_lfr),
            tristate = false,
            get = function(info, raid) return RaidSnacks:GetSetting("lfr", raid) end,
            set = function(info, raid, value) RaidSnacks:SetSetting("lfr", raid, value) end,
            order = 17,
        },
    },
}

local AceConfig = LibStub("AceConfig-3.0")
AceConfig:RegisterOptionsTable("RaidSnacks", options)
LibStub("AceConfig-3.0"):RegisterOptionsTable("RaidSnacks", options, {"raidsnacks", "snacks"})
RaidSnacks.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("RaidSnacks", "RaidSnacks")